/* -*- Mode: IDL; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozilla.org code.
 *
 * The Initial Developer of the Original Code is
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 2000
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *   Vidur Apparao <vidur@netscape.com> (original author)
 *   Johnny Stenback <jst@netscape.com>
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either of the GNU General Public License Version 2 or later (the "GPL"),
 * or the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#include "domstubs.idl"

[scriptable, uuid(8e150a70-3e51-45df-bee3-77505fbe016c)]
interface nsIDOMNavigator : nsISupports
{
  readonly attribute DOMString           appCodeName;
  readonly attribute DOMString           appName;
  readonly attribute DOMString           appVersion;
  readonly attribute DOMString           language;
  readonly attribute nsIDOMMimeTypeArray mimeTypes;
  readonly attribute DOMString           platform;
  readonly attribute DOMString           oscpu;
  readonly attribute DOMString           vendor;
  readonly attribute DOMString           vendorSub;
  readonly attribute DOMString           product;
  readonly attribute DOMString           productSub;
  readonly attribute nsIDOMPluginArray   plugins;
  readonly attribute DOMString           securityPolicy;
  readonly attribute DOMString           userAgent;
  readonly attribute boolean             cookieEnabled;
  readonly attribute boolean             onLine;
  readonly attribute DOMString           buildID;

  boolean                   javaEnabled();
  boolean                   taintEnabled();

  // XXX This one's tough, would nsISupports preference(in DOMString
  // pref /*, ... */); work?

  // jsval      preference(/* ... */);
};


[scriptable, uuid(4b4f8316-1dd2-11b2-b265-9a857376d159)]
interface nsIDOMJSNavigator : nsISupports
{
  // Nothing about this method (except it's name :-) is describeable
  // in XPIDL, argument handling and the return value needs to be
  // dealt with in the implementation of this method.
  void                      preference();
};
